@@ -1,13 +1,9 @@
 #----------------------------------------------------------------------
 package DBIx::DataModel::Statement::JDBC;
 #----------------------------------------------------------------------
-use strict;
-use warnings;
-no strict 'refs';
+use base qw/DBIx::DataModel::Statement/;
+use DBI  qw/SQL_INTEGER/;
 
-use parent qw/DBIx::DataModel::Statement/;
-use mro    qw/c3/;
-use DBI    qw/SQL_INTEGER/;
 
 # methods on the JDBC ResultSet object, without argument
 foreach my $method (qw/size           getRow
@@ -16,7 +12,6 @@ foreach my $method (qw/size           getRow
                        isBeforeFirst  isAfterLast/) {
   *{$method} = sub {
     my ($self) = @_;
-    $self->execute() if !$self->{sth};
     $self->{sth}->jdbc_func("ResultSet.$method");
   };
 }
@@ -25,7 +20,6 @@ foreach my $method (qw/size           getRow
 foreach my $method (qw/relative absolute/) {
   *{$method} = sub {
     my ($self, $int_arg) = @_;
-    $self->execute() if !$self->{sth};
     $self->{sth}->jdbc_func([$int_arg => SQL_INTEGER], "ResultSet.$method");
   };
 }
@@ -35,47 +29,44 @@ foreach my $method (qw/relative absolute/) {
 foreach my $method (qw/setMaxRows setQueryTimeout/) {
   *{$method} = sub {
     my ($self, $int_arg) = @_;
-    $self->prepare() if !$self->{sth};
     $self->{sth}->jdbc_func([$int_arg => SQL_INTEGER], "Statement.$method");
   };
 }
 
-sub sqlize {
-  my ($self, @args) = @_;
 
-  # merge new args into $self->{args}
-  $self->refine(@args) if @args;
+sub _limit_offset {
+  my ($self, $sql_ref, $bind_ref) = @_;
 
-  # remove -limit and -offset from args; they will be handled later in 
-  # prepare() and execute(), see below
-  $self->{jdbc_limit} = delete $self->{args}{-limit};
-  $self->{offset}     = delete $self->{args}{-offset} || 0;
+  $self->{offset} = $self->{args}{-offset} || 0;
 
-  $self->next::method();
+  # do nothing to the SQL or bind parameters (limit and offset
+  # will be handled in prepare() and execute(), see below)
 }
 
-
 sub prepare {
   my ($self, @args) = @_;
-  $self->next::method(@args);
-  my $limit = $self->{jdbc_limit};
+  my $limit = $self->{args}{-limit};
+  $self->SUPER::prepare(@args);
   $self->setMaxRows($limit + $self->{offset}) if $limit;
   return $self;
 }
 
+
 sub execute {
   my ($self, @args) = @_;
-  $self->next::method(@args);
+  $self->SUPER::execute(@args);
   $self->absolute($self->{offset}) if $self->{offset};
   return $self;
 }
 
-sub row_count {
+
+sub rowCount {
   my ($self) = @_;
-  $self->{row_count} = $self->getMemberCount unless exists $self->{row_count};
-  return $self->{row_count};
+  $self->{rowCount} = $self->getMemberCount unless exists $self->{rowCount};
+  return $self->{rowCount};
 }
 
+
 1;
 
 __END__
@@ -89,7 +80,7 @@ DBIx::DataModel::Statement::JDBC - Statement for interacting with DBD::JDBC
 When defining the L<DBIx::DataModel> Schema :
 
   DBIx::DataModel->Schema("MySchema",
-     statement_class => "DBIx::DataModel::Statement::JDBC",
+     statementClass => "DBIx::DataModel::Statement::JDBC"
   );
 
 When using the schema:
